pub fn read_lock<'a, T>(
lock: &'a RwLock<T>,
context: &str,
) -> Result<RwLockReadGuard<'a, T>>Expand description
Safe read lock acquisition with context for error messages
pub fn read_lock<'a, T>(
lock: &'a RwLock<T>,
context: &str,
) -> Result<RwLockReadGuard<'a, T>>Safe read lock acquisition with context for error messages