pub fn get_analytics() -> &'static Arc<RwLock<AnalyticsTracker>>Expand description
Get or initialize the global analytics tracker. On first call, loads persisted data from disk and starts periodic save.
pub fn get_analytics() -> &'static Arc<RwLock<AnalyticsTracker>>Get or initialize the global analytics tracker. On first call, loads persisted data from disk and starts periodic save.